/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/** @file i2c.h
 *  @brief Header file for I2C
 *
 *  Contains functions for I2C.
 *
 *  @author Kevin Woo and Suresh Nidhiry, Colony Project, CMU Robotics Club
 **/


#ifndef _I2C_H_
#define _I2C_H_

/** @brief Address of slave receive handler function **/
typedef void (*fun_srecv_t)(char);

/** @brief Address of master receive handler function**/
typedef int (*fun_mrecv_t)(char);

/** @brief Address of slave send handler function**/
typedef char (*fun_send_t)(void);

int i2c_init(char addr, fun_mrecv_t master_recv, fun_srecv_t slave_recv, fun_send_t slave_send);
int i2c_send(char dest, char* data, unsigned int bytes);
int i2c_request(char dest);

void i2c_packet_rec (char i2c_byte);
void i2c_packet_sniff(char data);
#endif

